/* Generated by tools/make-builtin-config.sh */
const char *builtin_config =
	"set blame-view	= id:yes,color file-name:auto author:full committer:no date:default,format=\"%Y-%m-%d\" line-number:yes,interval=1 text\n"
	"set grep-view	= file-name:no line-number:yes,interval=1 text\n"
	"set main-view	= line-number:no,interval=5 id:no date:default,format=\"%Y-%m-%d\" author:full committer:no commit-title:yes,graph,refs,overflow=no\n"
	"set reflog-view	= line-number:no,interval=5 id:yes date:no,format=\"%Y-%m-%d\" author:no committer:no commit-title:yes,refs,overflow=no\n"
	"set refs-view	= line-number:no id:no date:default,format=\"%Y-%m-%d\" author:full committer:no ref commit-title\n"
	"set stash-view	= line-number:no,interval=5 id:no date:default,format=\"%Y-%m-%d\" author:full commit-title\n"
	"set status-view	= line-number:no,interval=5 status:short file-name\n"
	"set tree-view	= line-number:no,interval=5 mode author:full committer:no file-size date:default,format=\"%Y-%m-%d\" id:no file-name\n"
	"set pager-view	= line-number:no,interval=5 text\n"
	"set stage-view	= line-number:no,interval=5 text\n"
	"set log-view	= line-number:no,interval=5 text\n"
	"set blob-view	= line-number:no,interval=5 text\n"
	"set diff-view	= line-number:no,interval=5 text:yes,commit-title-overflow=no\n"
	"set show-changes	= yes\n"
	"set show-untracked	= yes\n"
	"set wrap-lines	= no\n"
	"set tab-size	= 8\n"
	"set line-graphics	= default\n"
	"set truncation-delimiter	= ~\n"
	"set reference-format	= [branch] <tag> {remote} ~replace~\n"
	"set commit-order	= auto\n"
	"set status-show-untracked-dirs	= yes\n"
	"set status-show-untracked-files	= yes\n"
	"set ignore-space	= no\n"
	"set show-notes	= yes\n"
	"set diff-indicator	= yes\n"
	"set log-options	= --cc --stat\n"
	"set mailmap	= yes\n"
	"set start-on-head	= no\n"
	"set refresh-mode	= auto\n"
	"set refresh-interval	= 10\n"
	"set ignore-case	= no\n"
	"set wrap-search	= yes\n"
	"set focus-child	= yes\n"
	"set send-child-enter	= yes\n"
	"set horizontal-scroll	= 50%\n"
	"set split-view-height	= 67%\n"
	"set vertical-split	= auto\n"
	"set split-view-width	= 50%\n"
	"set editor-line-number	= yes\n"
	"set history-size	= 500\n"
	"set mouse	= no\n"
	"set mouse-scroll	= 3\n"
	"set mouse-wheel-cursor	= no\n"
	"set pgrp	= no\n"
	"set pager-autoscroll	= no\n"
	"set recurse-tree	= no\n"
	"bind main	C	?git cherry-pick %(commit)\n"
	"bind status	C	!git commit\n"
	"bind stash	A	?git stash apply %(stash)\n"
	"bind stash	P	?git stash pop %(stash)\n"
	"bind stash	!	?git stash drop %(stash)\n"
	"bind refs	C	?git checkout %(branch)\n"
	"bind refs	!	?git branch -D %(branch)\n"
	"bind reflog	C	?git checkout %(branch)\n"
	"bind reflog	!	?git reset --hard %(commit)\n"
	"bind generic	m	view-main\n"
	"bind generic	d	view-diff\n"
	"bind generic	l	view-log\n"
	"bind generic	L	view-reflog\n"
	"bind generic	t	view-tree\n"
	"bind generic	f	view-blob\n"
	"bind generic	b	view-blame\n"
	"bind generic	r	view-refs\n"
	"bind generic	p	view-pager\n"
	"bind generic	h	view-help\n"
	"bind generic	s	view-status\n"
	"bind generic	S	view-status\n"
	"bind generic	c	view-stage\n"
	"bind generic	y	view-stash\n"
	"bind generic	g	view-grep\n"
	"bind generic	<Enter>	enter\n"
	"bind generic	<Lt>	back\n"
	"bind generic	<Down>	next\n"
	"bind generic	<C-N>	next\n"
	"bind generic	J	next\n"
	"bind generic	<Up>	previous\n"
	"bind generic	<C-P>	previous\n"
	"bind generic	K	previous\n"
	"bind generic	,	parent\n"
	"bind generic	<Tab>	view-next\n"
	"bind generic	R	refresh\n"
	"bind generic	<F5>	refresh\n"
	"bind generic	O	maximize\n"
	"bind generic	q	view-close\n"
	"bind generic	Q	quit\n"
	"bind generic	<C-C>	quit\n"
	"bind status	u	status-update\n"
	"bind status	!	status-revert\n"
	"bind status	M	status-merge\n"
	"bind stage	u	status-update\n"
	"bind stage	1	stage-update-line\n"
	"bind stage	2	stage-update-part\n"
	"bind stage	!	status-revert\n"
	"bind stage	\\	stage-split-chunk\n"
	"bind stage	@	:/^@@\n"
	"bind stage	[	:toggle diff-context -1\n"
	"bind stage	]	:toggle diff-context +1\n"
	"bind diff	@	:/^@@\n"
	"bind diff	[	:toggle diff-context -1\n"
	"bind diff	]	:toggle diff-context +1\n"
	"bind pager	@	:/^@@\n"
	"bind main	H	:goto HEAD\n"
	"bind main	G	:toggle commit-title-graph\n"
	"bind main	F	:toggle commit-title-refs\n"
	"bind reflog	F	:toggle commit-title-refs\n"
	"bind generic	j	move-down\n"
	"bind generic	k	move-up\n"
	"bind generic	<C-D>	move-half-page-down\n"
	"bind generic	<C-U>	move-half-page-up\n"
	"bind generic	<PgDown> move-page-down\n"
	"bind generic	<Space>	move-page-down\n"
	"bind generic	<PgUp>	move-page-up\n"
	"bind generic	-	move-page-up\n"
	"bind generic	<Home>	move-first-line\n"
	"bind generic	<End>	move-last-line\n"
	"bind generic	|	scroll-first-col\n"
	"bind generic	<Left>	scroll-left\n"
	"bind generic	<Right>	scroll-right\n"
	"bind generic	<Ins>	scroll-line-up\n"
	"bind generic	<C-Y>	scroll-line-up\n"
	"bind generic	<Del>	scroll-line-down\n"
	"bind generic	<C-E>	scroll-line-down\n"
	"bind generic	<SBack>	scroll-page-up\n"
	"bind generic	<SFwd>	scroll-page-down\n"
	"bind generic	/	search\n"
	"bind generic	?	search-back\n"
	"bind generic	n	find-next\n"
	"bind generic	N	find-prev\n"
	"bind search	<Down>	find-next\n"
	"bind search	<C-N>	find-next\n"
	"bind search	<C-J>	find-next\n"
	"bind search	<Up>	find-prev\n"
	"bind search	<C-P>	find-prev\n"
	"bind search	<C-K>	find-prev\n"
	"bind search	<C-C>	view-close\n"
	"bind generic	o	options\n"
	"bind generic	I	:toggle sort-order\n"
	"bind generic	i	:toggle sort-field\n"
	"bind generic	<Hash>	:toggle line-number\n"
	"bind generic	D	:toggle date\n"
	"bind generic	A	:toggle author\n"
	"bind generic	T	:toggle committer\n"
	"bind generic	~	:toggle line-graphics\n"
	"bind generic	F	:toggle file-name\n"
	"bind generic	W	:toggle ignore-space\n"
	"bind generic	X	:toggle id\n"
	"bind generic	$	:toggle commit-title-overflow\n"
	"bind generic	%	:toggle file-filter\n"
	"bind generic	^	:toggle rev-filter\n"
	"bind generic	e	edit\n"
	"bind generic	:	prompt\n"
	"bind generic	<C-L>	screen-redraw\n"
	"bind generic	z	stop-loading\n"
	"bind generic	v	show-version\n"
	"color \"---\"	blue	default\n"
	"color \"diff --\"	yellow	default\n"
	"color \"--- \"	yellow	default\n"
	"color \"+++ \"	yellow	default\n"
	"color \"@@\"	magenta	default\n"
	"color \"+\"	green	default\n"
	"color \" +\"	green	default\n"
	"color \"-\"	red	default\n"
	"color \" -\"	red	default\n"
	"color \"index \"	blue	default\n"
	"color \"old mode \"	yellow	default\n"
	"color \"new mode \"	yellow	default\n"
	"color \"new file mode \"	yellow	default\n"
	"color \"deleted file mode \"	yellow	default\n"
	"color \"copy from \"	yellow	default\n"
	"color \"copy to \"	yellow	default\n"
	"color \"rename from \"	yellow	default\n"
	"color \"rename to \"	yellow	default\n"
	"color \"similarity \"	yellow	default\n"
	"color \"dissimilarity \"	yellow	default\n"
	"color \"\\ No newline at end of file\"	blue	default\n"
	"color \"diff-tree \"	blue	default\n"
	"color \"Author: \"	cyan	default\n"
	"color \"Commit: \"	magenta	default\n"
	"color \"Tagger: \"	magenta	default\n"
	"color \"Merge: \"	blue	default\n"
	"color \"Date: \"	yellow	default\n"
	"color \"AuthorDate: \"	yellow	default\n"
	"color \"CommitDate: \"	yellow	default\n"
	"color \"TaggerDate: \"	yellow	default\n"
	"color \"Refs: \"	red	default\n"
	"color \"Reflog: \"	red	default\n"
	"color \"Reflog message: \"	yellow	default\n"
	"color \"stash@{\"	magenta	default\n"
	"color \"commit \"	green	default\n"
	"color \"parent \"	blue	default\n"
	"color \"tree \"	blue	default\n"
	"color \"author \"	green	default\n"
	"color \"committer \"	magenta	default\n"
	"color \"    Signed-off-by:\"	yellow	default\n"
	"color \"    Acked-by:\"	yellow	default\n"
	"color \"    Reviewed-by:\"	yellow	default\n"
	"color \"    Helped-by:\"	yellow	default\n"
	"color \"    Reported-by:\"	yellow	default\n"
	"color \"    Mentored-by:\"	yellow	default\n"
	"color \"    Suggested-by:\"	yellow	default\n"
	"color \"    Cc:\"	yellow	default\n"
	"color \"    Noticed-by:\"	yellow	default\n"
	"color \"    Tested-by:\"	yellow	default\n"
	"color \"    Improved-by:\"	yellow	default\n"
	"color \"    Thanks-to:\"	yellow	default\n"
	"color \"    Based-on-patch-by:\"	yellow	default\n"
	"color \"    Contributions-by:\"	yellow	default\n"
	"color \"    Co-authored-by:\"	yellow	default\n"
	"color \"    Requested-by:\"	yellow	default\n"
	"color \"    Original-patch-by:\"	yellow	default\n"
	"color \"    Inspired-by:\"	yellow	default\n"
	"color \"    Generated-by:\"	yellow	default\n"
	"color \"    Assisted-by:\"	yellow	default\n"
	"color default	default	default	normal\n"
	"color cursor	white	green	bold\n"
	"color cursor-blur	white	green\n"
	"color status	green	default\n"
	"color delimiter	magenta	default\n"
	"color date	blue	default\n"
	"color mode	cyan	default\n"
	"color id	magenta	default\n"
	"color overflow	red	default\n"
	"color header	yellow	default\n"
	"color section	cyan	default\n"
	"color directory	yellow	default\n"
	"color file	default	default\n"
	"color grep.file	blue	default\n"
	"color file-size	default	default\n"
	"color line-number	cyan	default\n"
	"color title-blur	white	blue\n"
	"color title-focus	white	blue	bold\n"
	"color main-commit	default	default\n"
	"color main-annotated	default	default	bold\n"
	"color main-tag	magenta	default	bold\n"
	"color main-local-tag	magenta	default\n"
	"color main-remote	yellow	default\n"
	"color main-stash	blue	default\n"
	"color main-note	blue	default\n"
	"color main-prefetch	blue	default\n"
	"color main-other	blue	default\n"
	"color main-replace	cyan	default\n"
	"color main-tracked	yellow	default	bold\n"
	"color main-ref	cyan	default\n"
	"color main-head	cyan	default	bold\n"
	"color stat-none	default	default\n"
	"color stat-staged	magenta	default\n"
	"color stat-unstaged	magenta	default\n"
	"color stat-untracked	magenta	default\n"
	"color help-group	blue	default\n"
	"color help-action	yellow	default\n"
	"color diff-stat	blue	default\n"
	"color diff-add-highlight	green	default	standout\n"
	"color diff-del-highlight	red	default	standout\n"
	"color palette-0	magenta	default\n"
	"color palette-1	yellow	default\n"
	"color palette-2	cyan	default\n"
	"color palette-3	green	default\n"
	"color palette-4	default	default\n"
	"color palette-5	white	default\n"
	"color palette-6	red	default\n"
	"color palette-7	magenta	default	bold\n"
	"color palette-8	yellow	default	bold\n"
	"color palette-9	cyan	default	bold\n"
	"color palette-10	green	default	bold\n"
	"color palette-11	default	default	bold\n"
	"color palette-12	white	default	bold\n"
	"color palette-13	red	default	bold\n"
	"color graph-commit	blue	default\n"
	"color search-result	black	yellow\n"
	"set git-colors = \\\n"
	"branch.current=main-head \\\n"
	"branch.local=main-ref \\\n"
	"branch.plain=main-ref \\\n"
	"branch.remote=main-remote \\\n"
	"\\\n"
	"diff.meta=diff-header \\\n"
	"diff.meta=diff-index \\\n"
	"diff.meta=diff-oldmode \\\n"
	"diff.meta=diff-newmode \\\n"
	"diff.frag=diff-chunk \\\n"
	"diff.old=diff-del \\\n"
	"diff.new=diff-add \\\n"
	"\\\n"
	"diff-highlight.oldHighlight=diff-del-highlight \\\n"
	"diff-highlight.newHighlight=diff-add-highlight \\\n"
	"\\\n"
	"grep.filename=grep.file \\\n"
	"grep.linenumber=grep.line-number \\\n"
	"grep.separator=grep.delimiter \\\n"
	"\\\n"
	"status.branch=status.header \\\n"
	"status.added=stat-staged \\\n"
	"status.updated=stat-staged \\\n"
	"status.changed=stat-unstaged \\\n"
	"status.untracked=stat-untracked\n"
;
